@@ -244,8 +244,7 @@ export const dndGranularitySqlaControl: typeof dndSeriesControl = {
   default: (c: Control) => c.default,
   clearable: false,
   canDelete: false,
-  ghostButtonText: t('Drop temporal column here'),
-  clickEnabledGhostButtonText: t('Drop a temporal column here or click'),
+  ghostButtonText: t('Drop a temporal column here or click'),
   optionRenderer: (c: ColumnMeta) => <ColumnOption showType column={c} />,
   valueRenderer: (c: ColumnMeta) => <ColumnOption column={c} />,
   valueKey: 'column_name',
