@@ -69,8 +69,23 @@ const config: ControlPanelConfig = {
       controlSetRows: [
         [fillColorPicker, strokeColorPicker],
         [filled, stroked],
-        [extruded, null],
-        [lineWidth, null],
+        [extruded],
+        [lineWidth],
+        [
+          {
+            name: 'line_width_unit',
+            config: {
+              type: 'SelectControl',
+              label: t('Line width unit'),
+              default: 'meters',
+              choices: [
+                ['meters', t('meters')],
+                ['pixels', t('pixels')],
+              ],
+              renderTrigger: true,
+            },
+          },
+        ],
         [
           {
             name: 'point_radius_scale',
@@ -83,7 +98,6 @@ const config: ControlPanelConfig = {
               choices: formatSelectOptions([0, 100, 200, 300, 500]),
             },
           },
-          null,
         ],
       ],
     },
