@@ -57,11 +57,13 @@ export const DEFAULT_FORM_DATA: EchartsTimeseriesFormData = {
   seriesType: EchartsTimeseriesSeriesType.Line,
   stack: false,
   tooltipTimeFormat: 'smart_date',
+  truncateXAxis: true,
   truncateYAxis: false,
   yAxisBounds: [null, null],
   zoomable: false,
   richTooltip: true,
   xAxisLabelRotation: 0,
+  xAxisForceCategorical: false,
   groupby: [],
   showValue: false,
   onlyTotal: false,
