@@ -25,6 +25,10 @@ import App from 'src/SqlLab/components/App';
 import sqlLabReducer from 'src/SqlLab/reducers/index';
 import { LOCALSTORAGE_MAX_USAGE_KB } from 'src/SqlLab/constants';
 import { LOG_EVENT } from 'src/logger/actions';
+import {
+  LOG_ACTIONS_SQLLAB_WARN_LOCAL_STORAGE_USAGE,
+  LOG_ACTIONS_SQLLAB_MONITOR_LOCAL_STORAGE_USAGE,
+} from 'src/logger/LogUtils';
 
 jest.mock('src/SqlLab/components/TabbedSqlEditors', () => () => (
   <div data-test="mock-tabbed-sql-editors" />
@@ -54,7 +58,7 @@ describe('SqlLab App', () => {
     expect(getByTestId('mock-tabbed-sql-editors')).toBeInTheDocument();
   });
 
-  it('logs current usage warning', async () => {
+  it('logs current usage warning', () => {
     const localStorageUsageInKilobytes = LOCALSTORAGE_MAX_USAGE_KB + 10;
     const storeExceedLocalStorage = mockStore(
       sqlLabReducer(
@@ -73,6 +77,38 @@ describe('SqlLab App', () => {
     expect(storeExceedLocalStorage.getActions()).toContainEqual(
       expect.objectContaining({
         type: LOG_EVENT,
+        payload: expect.objectContaining({
+          eventName: LOG_ACTIONS_SQLLAB_WARN_LOCAL_STORAGE_USAGE,
+        }),
+      }),
+    );
+  });
+
+  it('logs current local storage usage', () => {
+    const localStorageUsageInKilobytes = LOCALSTORAGE_MAX_USAGE_KB - 10;
+    const storeExceedLocalStorage = mockStore(
+      sqlLabReducer(
+        {
+          localStorageUsageInKilobytes,
+        },
+        {},
+      ),
+    );
+
+    const { rerender } = render(<App />, {
+      useRedux: true,
+      store: storeExceedLocalStorage,
+    });
+    rerender(<App updated />);
+    expect(storeExceedLocalStorage.getActions()).toContainEqual(
+      expect.objectContaining({
+        type: LOG_EVENT,
+        payload: expect.objectContaining({
+          eventName: LOG_ACTIONS_SQLLAB_MONITOR_LOCAL_STORAGE_USAGE,
+          eventData: expect.objectContaining({
+            current_usage: localStorageUsageInKilobytes,
+          }),
+        }),
       }),
     );
   });
