@@ -19,7 +19,7 @@
 import userEvent from '@testing-library/user-event';
 import React from 'react';
 import { render, screen } from 'spec/helpers/testing-library';
-import { Indicator } from 'src/dashboard/components/FiltersBadge/selectors';
+import { Indicator } from 'src/dashboard/components/nativeFilters/selectors';
 import DetailsPanel from '.';
 
 const createProps = () => ({
@@ -86,7 +86,7 @@ const createProps = () => ({
   onHighlightFilterSource: jest.fn(),
 });
 
-test('Should render "appliedCrossFilterIndicators"', () => {
+test('Should render "appliedCrossFilterIndicators"', async () => {
   const props = createProps();
   props.appliedIndicators = [];
   props.incompatibleIndicators = [];
@@ -99,8 +99,10 @@ test('Should render "appliedCrossFilterIndicators"', () => {
     { useRedux: true },
   );
 
-  userEvent.click(screen.getByTestId('details-panel-content'));
-  expect(screen.getByText('Applied Cross Filters (1)')).toBeInTheDocument();
+  userEvent.hover(screen.getByTestId('details-panel-content'));
+  expect(
+    await screen.findByText('Applied cross-filters (1)'),
+  ).toBeInTheDocument();
   expect(
     screen.getByRole('button', { name: 'Clinical Stage' }),
   ).toBeInTheDocument();
@@ -118,7 +120,7 @@ test('Should render "appliedCrossFilterIndicators"', () => {
   ]);
 });
 
-test('Should render "appliedIndicators"', () => {
+test('Should render "appliedIndicators"', async () => {
   const props = createProps();
   props.appliedCrossFilterIndicators = [];
   props.incompatibleIndicators = [];
@@ -131,8 +133,8 @@ test('Should render "appliedIndicators"', () => {
     { useRedux: true },
   );
 
-  userEvent.click(screen.getByTestId('details-panel-content'));
-  expect(screen.getByText('Applied Filters (1)')).toBeInTheDocument();
+  userEvent.hover(screen.getByTestId('details-panel-content'));
+  expect(await screen.findByText('Applied filters (1)')).toBeInTheDocument();
   expect(screen.getByRole('button', { name: 'Country' })).toBeInTheDocument();
 
   expect(props.onHighlightFilterSource).toBeCalledTimes(0);
@@ -148,72 +150,6 @@ test('Should render "appliedIndicators"', () => {
   ]);
 });
 
-test('Should render "incompatibleIndicators"', () => {
-  const props = createProps();
-  props.appliedCrossFilterIndicators = [];
-  props.appliedIndicators = [];
-  props.unsetIndicators = [];
-
-  render(
-    <DetailsPanel {...props}>
-      <div data-test="details-panel-content">Content</div>
-    </DetailsPanel>,
-    { useRedux: true },
-  );
-
-  userEvent.click(screen.getByTestId('details-panel-content'));
-  expect(screen.getByText('Incompatible Filters (1)')).toBeInTheDocument();
-  expect(
-    screen.getByRole('button', { name: 'Vaccine Approach Copy' }),
-  ).toBeInTheDocument();
-
-  expect(props.onHighlightFilterSource).toBeCalledTimes(0);
-  userEvent.click(
-    screen.getByRole('button', { name: 'Vaccine Approach Copy' }),
-  );
-  expect(props.onHighlightFilterSource).toBeCalledTimes(1);
-  expect(props.onHighlightFilterSource).toBeCalledWith([
-    'ROOT_ID',
-    'TABS-wUKya7eQ0Zz',
-    'TAB-BCIJF4NvgQq',
-    'ROW-xSeNAspgww',
-    'CHART-eirDduqb1Aa',
-    'LABEL-product_category_copy',
-  ]);
-});
-
-test('Should render "unsetIndicators"', () => {
-  const props = createProps();
-  props.appliedCrossFilterIndicators = [];
-  props.appliedIndicators = [];
-  props.incompatibleIndicators = [];
-
-  render(
-    <DetailsPanel {...props}>
-      <div data-test="details-panel-content">Content</div>
-    </DetailsPanel>,
-    { useRedux: true },
-  );
-
-  userEvent.click(screen.getByTestId('details-panel-content'));
-  expect(screen.getByText('Unset Filters (1)')).toBeInTheDocument();
-  expect(
-    screen.getByRole('button', { name: 'Vaccine Approach' }),
-  ).toBeInTheDocument();
-
-  expect(props.onHighlightFilterSource).toBeCalledTimes(0);
-  userEvent.click(screen.getByRole('button', { name: 'Vaccine Approach' }));
-  expect(props.onHighlightFilterSource).toBeCalledTimes(1);
-  expect(props.onHighlightFilterSource).toBeCalledWith([
-    'ROOT_ID',
-    'TABS-wUKya7eQ0Z',
-    'TAB-BCIJF4NvgQ',
-    'ROW-xSeNAspgw',
-    'CHART-eirDduqb1A',
-    'LABEL-product_category',
-  ]);
-});
-
 test('Should render empty', () => {
   const props = createProps();
   props.appliedCrossFilterIndicators = [];
