@@ -90,6 +90,11 @@ const DragDroppableStyles = styled.div`
       z-index: 10;
     }
 
+    &.empty-droptarget--full > .drop-indicator--top {
+      height: 100%;
+      opacity: 0.3;
+    }
+
     & {
       .drop-indicator {
         display: block;
@@ -99,7 +104,7 @@ const DragDroppableStyles = styled.div`
       }
 
       .drop-indicator--top {
-        top: 0;
+        top: ${-theme.gridUnit - 2}px;
         left: 0;
         height: ${theme.gridUnit}px;
         width: 100%;
@@ -107,7 +112,7 @@ const DragDroppableStyles = styled.div`
       }
 
       .drop-indicator--bottom {
-        top: 100%;
+        bottom: ${-theme.gridUnit - 2}px;
         left: 0;
         height: ${theme.gridUnit}px;
         width: 100%;
@@ -116,7 +121,7 @@ const DragDroppableStyles = styled.div`
 
       .drop-indicator--right {
         top: 0;
-        left: 100%;
+        left: calc(100% - ${theme.gridUnit}px);
         height: 100%;
         width: ${theme.gridUnit}px;
         min-height: ${theme.gridUnit * 4}px;
