@@ -39,10 +39,12 @@ import {
   UNSET_FOCUSED_FILTER_FIELD,
   SET_ACTIVE_TABS,
   SET_FULL_SIZE_CHART_ID,
-  RESET_SLICE,
   ON_FILTERS_REFRESH,
   ON_FILTERS_REFRESH_SUCCESS,
   SET_DATASETS_STATUS,
+  SET_OVERRIDE_CONFIRM,
+  SAVE_DASHBOARD_STARTED,
+  SAVE_DASHBOARD_FINISHED,
 } from '../actions/dashboardState';
 import { HYDRATE_DASHBOARD } from '../actions/hydrate';
 
@@ -60,7 +62,6 @@ export default function dashboardStateReducer(state = {}, action) {
       return {
         ...state,
         sliceIds: Array.from(updatedSliceIds),
-        updateSlice: true,
       };
     },
     [REMOVE_SLICE]() {
@@ -73,12 +74,6 @@ export default function dashboardStateReducer(state = {}, action) {
         sliceIds: Array.from(updatedSliceIds),
       };
     },
-    [RESET_SLICE]() {
-      return {
-        ...state,
-        updateSlice: false,
-      };
-    },
     [TOGGLE_FAVE_STAR]() {
       return { ...state, isStarred: action.isStarred };
     },
@@ -118,6 +113,18 @@ export default function dashboardStateReducer(state = {}, action) {
     [ON_CHANGE]() {
       return { ...state, hasUnsavedChanges: true };
     },
+    [SAVE_DASHBOARD_STARTED]() {
+      return {
+        ...state,
+        dashboardIsSaving: true,
+      };
+    },
+    [SAVE_DASHBOARD_FINISHED]() {
+      return {
+        ...state,
+        dashboardIsSaving: false,
+      };
+    },
     [ON_SAVE]() {
       return {
         ...state,
@@ -125,7 +132,6 @@ export default function dashboardStateReducer(state = {}, action) {
         maxUndoHistoryExceeded: false,
         editMode: false,
         updatedColorScheme: false,
-        updateSlice: false,
         // server-side returns last_modified_time for latest change
         lastModifiedTime: action.lastModifiedTime,
       };
@@ -182,6 +188,12 @@ export default function dashboardStateReducer(state = {}, action) {
         activeTabs: Array.from(newActiveTabs),
       };
     },
+    [SET_OVERRIDE_CONFIRM]() {
+      return {
+        ...state,
+        overwriteConfirmMetadata: action.overwriteConfirmMetadata,
+      };
+    },
     [SET_FOCUSED_FILTER_FIELD]() {
       return {
         ...state,
