@@ -18,23 +18,13 @@
  */
 
 import componentTypes from 'src/dashboard/util/componentTypes';
-import { NativeFilterScope, JsonObject } from '@superset-ui/core';
+import { JsonObject } from '@superset-ui/core';
 
 export enum Scoping {
   All = 'All',
   Specific = 'Specific',
 }
 
-export type ChartConfiguration = {
-  [chartId: number]: {
-    id: number;
-    crossFilters: {
-      scope: NativeFilterScope;
-      chartsInScope: number[];
-    };
-  };
-};
-
 export type User = {
   email: string;
   firstName: string;
