@@ -19,9 +19,11 @@
 import {
   ChartProps,
   DataMaskStateWithId,
+  DatasourceType,
   ExtraFormData,
   GenericDataType,
   JsonObject,
+  NativeFilterScope,
   NativeFiltersState,
 } from '@superset-ui/core';
 import { Dataset } from '@superset-ui/chart-controls';
@@ -32,7 +34,7 @@ import { UrlParamEntries } from 'src/utils/urlUtils';
 import { UserWithPermissionsAndRoles } from 'src/types/bootstrapTypes';
 import { ChartState } from '../explore/types';
 
-export { Dashboard } from 'src/types/Dashboard';
+export type { Dashboard } from 'src/types/Dashboard';
 
 export type ChartReducerInitialState = typeof chart;
 
@@ -57,6 +59,28 @@ export enum FilterBarOrientation {
   HORIZONTAL = 'HORIZONTAL',
 }
 
+// chart's cross filter scoping can have its custom value or point to the global configuration
+export const GLOBAL_SCOPE_POINTER = 'global';
+export type GlobalScopePointer = typeof GLOBAL_SCOPE_POINTER;
+export type ChartCrossFiltersConfig = {
+  scope: NativeFilterScope | GlobalScopePointer;
+  chartsInScope: number[];
+};
+export type GlobalChartCrossFilterConfig = {
+  scope: NativeFilterScope;
+  chartsInScope: number[];
+};
+export const isCrossFilterScopeGlobal = (
+  scope: NativeFilterScope | GlobalScopePointer,
+): scope is GlobalScopePointer => scope === GLOBAL_SCOPE_POINTER;
+
+export type ChartConfiguration = {
+  [chartId: number]: {
+    id: number;
+    crossFilters: ChartCrossFiltersConfig;
+  };
+};
+
 export type ActiveTabs = string[];
 export type DashboardLayout = { [key: string]: LayoutItem };
 export type DashboardLayoutState = { present: DashboardLayout };
@@ -101,8 +125,8 @@ export type DashboardInfo = {
   json_metadata: string;
   metadata: {
     native_filter_configuration: JsonObject;
-    show_native_filters: boolean;
-    chart_configuration: JsonObject;
+    chart_configuration: ChartConfiguration;
+    global_chart_configuration: GlobalChartCrossFilterConfig;
     color_scheme: string;
     color_namespace: string;
     color_scheme_domain: string[];
@@ -194,3 +218,23 @@ export type EmbeddedDashboard = {
   dashboard_id: string;
   allowed_domains: string[];
 };
+
+export type Slice = {
+  slice_id: number;
+  slice_name: string;
+  description: string;
+  description_markdown: string;
+  form_data: any;
+  slice_url: string;
+  viz_type: string;
+  thumbnail_url: string;
+  changed_on: number;
+  changed_on_humanized: string;
+  modified: string;
+  datasource_id: number;
+  datasource_type: DatasourceType;
+  datasource_url: string;
+  datasource_name: string;
+  owners: { id: number }[];
+  created_by: { id: number };
+};
