@@ -17,6 +17,7 @@
  * under the License.
  */
 /* eslint camelcase: 0 */
+import rison from 'rison';
 import { Dataset } from '@superset-ui/chart-controls';
 import { t, SupersetClient, QueryFormData } from '@superset-ui/core';
 import { Dispatch } from 'redux';
@@ -27,8 +28,6 @@ import {
 import { Slice } from 'src/types/Chart';
 import { SaveActionType } from 'src/explore/types';
 
-const FAVESTAR_BASE_URL = '/superset/favstar/slice';
-
 export const UPDATE_FORM_DATA_BY_DATASOURCE = 'UPDATE_FORM_DATA_BY_DATASOURCE';
 export function updateFormDataByDatasource(
   prevDatasource: Dataset,
@@ -66,11 +65,9 @@ export const FETCH_FAVE_STAR = 'FETCH_FAVE_STAR';
 export function fetchFaveStar(sliceId: string) {
   return function (dispatch: Dispatch) {
     SupersetClient.get({
-      endpoint: `${FAVESTAR_BASE_URL}/${sliceId}/count/`,
+      endpoint: `/api/v1/chart/favorite_status/?q=${rison.encode([sliceId])}`,
     }).then(({ json }) => {
-      if (json.count > 0) {
-        dispatch(toggleFaveStar(true));
-      }
+      dispatch(toggleFaveStar(!!json?.result?.[0]?.value));
     });
   };
 }
@@ -78,10 +75,14 @@ export function fetchFaveStar(sliceId: string) {
 export const SAVE_FAVE_STAR = 'SAVE_FAVE_STAR';
 export function saveFaveStar(sliceId: string, isStarred: boolean) {
   return function (dispatch: Dispatch) {
-    const urlSuffix = isStarred ? 'unselect' : 'select';
-    SupersetClient.get({
-      endpoint: `${FAVESTAR_BASE_URL}/${sliceId}/${urlSuffix}/`,
-    })
+    const endpoint = `/api/v1/chart/${sliceId}/favorites/`;
+    const apiCall = isStarred
+      ? SupersetClient.delete({
+          endpoint,
+        })
+      : SupersetClient.post({ endpoint });
+
+    apiCall
       .then(() => dispatch(toggleFaveStar(!isStarred)))
       .catch(() => {
         dispatch(
