@@ -16,7 +16,7 @@
 # under the License.
 import logging
 from datetime import datetime
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional
 
 from flask import g
 from flask_appbuilder.models.sqla import Model
@@ -31,31 +31,33 @@ from superset.charts.commands.exceptions import (
     DashboardsNotFoundValidationError,
     DatasourceTypeUpdateRequiredValidationError,
 )
-from superset.charts.dao import ChartDAO
 from superset.commands.base import BaseCommand, UpdateMixin
 from superset.commands.utils import get_datasource_by_id
-from superset.dao.exceptions import DAOUpdateFailedError
-from superset.dashboards.dao import DashboardDAO
+from superset.daos.chart import ChartDAO
+from superset.daos.dashboard import DashboardDAO
+from superset.daos.exceptions import DAOUpdateFailedError
 from superset.exceptions import SupersetSecurityException
 from superset.models.slice import Slice
 
 logger = logging.getLogger(__name__)
 
 
-def is_query_context_update(properties: Dict[str, Any]) -> bool:
+def is_query_context_update(properties: dict[str, Any]) -> bool:
     return set(properties) == {"query_context", "query_context_generation"} and bool(
         properties.get("query_context_generation")
     )
 
 
 class UpdateChartCommand(UpdateMixin, BaseCommand):
-    def __init__(self, model_id: int, data: Dict[str, Any]):
+    def __init__(self, model_id: int, data: dict[str, Any]):
         self._model_id = model_id
         self._properties = data.copy()
         self._model: Optional[Slice] = None
 
     def run(self) -> Model:
         self.validate()
+        assert self._model
+
         try:
             if self._properties.get("query_context_generation") is None:
                 self._properties["last_saved_at"] = datetime.now()
@@ -67,9 +69,9 @@ class UpdateChartCommand(UpdateMixin, BaseCommand):
         return chart
 
     def validate(self) -> None:
-        exceptions: List[ValidationError] = []
+        exceptions: list[ValidationError] = []
         dashboard_ids = self._properties.get("dashboards")
-        owner_ids: Optional[List[int]] = self._properties.get("owners")
+        owner_ids: Optional[list[int]] = self._properties.get("owners")
 
         # Validate if datasource_id is provided datasource_type is required
         datasource_id = self._properties.get("datasource_id")
@@ -114,6 +116,4 @@ class UpdateChartCommand(UpdateMixin, BaseCommand):
             self._properties["dashboards"] = dashboards
 
         if exceptions:
-            exception = ChartInvalidError()
-            exception.add_list(exceptions)
-            raise exception
+            raise ChartInvalidError(exceptions=exceptions)
