@@ -169,35 +169,6 @@ def create_slices(tbl: BaseDatasource) -> list[Slice]:
     }
 
     return [
-        Slice(
-            slice_name="Region Filter",
-            viz_type="filter_box",
-            datasource_type=DatasourceType.TABLE,
-            datasource_id=tbl.id,
-            params=get_slice_json(
-                defaults,
-                viz_type="filter_box",
-                date_filter=False,
-                filter_configs=[
-                    {
-                        "asc": False,
-                        "clearable": True,
-                        "column": "region",
-                        "key": "2s98dfu",
-                        "metric": "sum__SP_POP_TOTL",
-                        "multiple": False,
-                    },
-                    {
-                        "asc": False,
-                        "clearable": True,
-                        "key": "li3j2lk",
-                        "column": "country_name",
-                        "metric": "sum__SP_POP_TOTL",
-                        "multiple": True,
-                    },
-                ],
-            ),
-        ),
         Slice(
             slice_name="World's Population",
             viz_type="big_number",
@@ -374,18 +345,12 @@ def create_slices(tbl: BaseDatasource) -> list[Slice]:
 
 
 dashboard_positions = {
-    "CHART-36bfc934": {
-        "children": [],
-        "id": "CHART-36bfc934",
-        "meta": {"chartId": 40, "height": 25, "sliceName": "Region Filter", "width": 2},
-        "type": "CHART",
-    },
     "CHART-37982887": {
         "children": [],
         "id": "CHART-37982887",
         "meta": {
             "chartId": 41,
-            "height": 25,
+            "height": 52,
             "sliceName": "World's Population",
             "width": 2,
         },
@@ -466,7 +431,7 @@ dashboard_positions = {
         "type": "COLUMN",
     },
     "COLUMN-fe3914b8": {
-        "children": ["CHART-36bfc934", "CHART-37982887"],
+        "children": ["CHART-37982887"],
         "id": "COLUMN-fe3914b8",
         "meta": {"background": "BACKGROUND_TRANSPARENT", "width": 2},
         "type": "COLUMN",
