@@ -22,6 +22,11 @@ import pandas as pd
 
 def df_to_excel(df: pd.DataFrame, **kwargs: Any) -> Any:
     output = io.BytesIO()
+
+    # timezones are not supported
+    for column in df.select_dtypes(include=["datetimetz"]).columns:
+        df[column] = df[column].astype(str)
+
     # pylint: disable=abstract-class-instantiated
     with pd.ExcelWriter(output, engine="xlsxwriter") as writer:
         df.to_excel(writer, **kwargs)
