@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 import hashlib
-from typing import Any, Callable, Dict, Optional
+from typing import Any, Callable, Optional
 
 import simplejson as json
 
@@ -25,7 +25,7 @@ def md5_sha_from_str(val: str) -> str:
 
 
 def md5_sha_from_dict(
-    obj: Dict[Any, Any],
+    obj: dict[Any, Any],
     ignore_nan: bool = False,
     default: Optional[Callable[[Any], Any]] = None,
 ) -> str:
