@@ -15,7 +15,6 @@
 # specific language governing permissions and limitations
 # under the License.
 """Contains the logic to create cohesive forms on the explore view"""
-from typing import List
 
 from flask_appbuilder.fields import QuerySelectField
 from flask_appbuilder.fieldwidgets import BS3TextFieldWidget
@@ -44,7 +43,7 @@ config = app.config
 
 class UploadToDatabaseForm(DynamicForm):
     @staticmethod
-    def file_allowed_dbs() -> List[Database]:
+    def file_allowed_dbs() -> list[Database]:
         file_enabled_dbs = (
             db.session.query(Database).filter_by(allow_file_upload=True).all()
         )
@@ -140,6 +139,16 @@ class CsvToDatabaseForm(UploadToDatabaseForm):
         get_pk_func=lambda a: a.id,
         get_label=lambda a: a.database_name,
     )
+    dtype = StringField(
+        _("Column Data Types"),
+        description=_(
+            "A dictionary with column names and their data types"
+            " if you need to change the defaults."
+            ' Example: {"user_id":"integer"}'
+        ),
+        validators=[Optional()],
+        widget=BS3TextFieldWidget(),
+    )
     schema = StringField(
         _("Schema"),
         description=_("Select a schema if the database supports this"),
@@ -190,6 +199,10 @@ class CsvToDatabaseForm(UploadToDatabaseForm):
         _("Interpret Datetime Format Automatically"),
         description=_("Interpret the datetime format automatically"),
     )
+    day_first = BooleanField(
+        _("Day First"),
+        description=_("DD/MM format dates, international and European format"),
+    )
     decimal = StringField(
         _("Decimal Character"),
         default=".",
