@@ -17,7 +17,7 @@
 import json
 from contextlib import contextmanager
 from datetime import datetime, timedelta, timezone
-from typing import List, Optional
+from typing import Optional
 from unittest.mock import call, Mock, patch
 from uuid import uuid4
 
@@ -100,7 +100,7 @@ pytestmark = pytest.mark.usefixtures(
 )
 
 
-def get_target_from_report_schedule(report_schedule: ReportSchedule) -> List[str]:
+def get_target_from_report_schedule(report_schedule: ReportSchedule) -> list[str]:
     return [
         json.loads(recipient.recipient_config_json)["target"]
         for recipient in report_schedule.recipients
@@ -466,7 +466,6 @@ def create_alert_email_chart(request):
         chart = db.session.query(Slice).first()
         example_database = get_example_database()
         with create_test_table_context(example_database):
-
             report_schedule = create_report_notification(
                 email_target="target@email.com",
                 chart=chart,
@@ -549,7 +548,6 @@ def create_no_alert_email_chart(request):
         chart = db.session.query(Slice).first()
         example_database = get_example_database()
         with create_test_table_context(example_database):
-
             report_schedule = create_report_notification(
                 email_target="target@email.com",
                 chart=chart,
@@ -584,7 +582,6 @@ def create_mul_alert_email_chart(request):
         chart = db.session.query(Slice).first()
         example_database = get_example_database()
         with create_test_table_context(example_database):
-
             report_schedule = create_report_notification(
                 email_target="target@email.com",
                 chart=chart,
@@ -619,7 +616,6 @@ def create_invalid_sql_alert_email_chart(request):
         chart = db.session.query(Slice).first()
         example_database = get_example_database()
         with create_test_table_context(example_database):
-
             report_schedule = create_report_notification(
                 email_target="target@email.com",
                 chart=chart,
@@ -1072,7 +1068,6 @@ def test_email_dashboard_report_schedule(
 
     with freeze_time("2020-01-01T00:00:00Z"):
         with patch.object(current_app.config["STATS_LOGGER"], "gauge") as statsd_mock:
-
             AsyncExecuteReportScheduleCommand(
                 TEST_ID, create_report_email_dashboard.id, datetime.utcnow()
             ).run()
@@ -1143,7 +1138,6 @@ def test_slack_chart_report_schedule(
 
     with freeze_time("2020-01-01T00:00:00Z"):
         with patch.object(current_app.config["STATS_LOGGER"], "gauge") as statsd_mock:
-
             AsyncExecuteReportScheduleCommand(
                 TEST_ID, create_report_slack_chart.id, datetime.utcnow()
             ).run()
@@ -1192,7 +1186,6 @@ def test_slack_chart_report_schedule_with_errors(
         web_client_mock.side_effect = er
 
         with pytest.raises(ReportScheduleClientErrorsException):
-
             AsyncExecuteReportScheduleCommand(
                 TEST_ID, create_report_slack_chart.id, datetime.utcnow()
             ).run()
@@ -1349,7 +1342,6 @@ def test_report_schedule_working_timeout(create_report_slack_chart_working):
         seconds=create_report_slack_chart_working.working_timeout + 1
     )
     with freeze_time(current_time):
-
         with pytest.raises(ReportScheduleWorkingTimeoutError):
             AsyncExecuteReportScheduleCommand(
                 TEST_ID, create_report_slack_chart_working.id, datetime.utcnow()
@@ -1963,7 +1955,7 @@ def test_grace_period_error_flap(
 @pytest.mark.usefixtures(
     "load_birth_names_dashboard_with_slices", "create_report_email_dashboard"
 )
-@patch("superset.reports.dao.ReportScheduleDAO.bulk_delete_logs")
+@patch("superset.daos.report.ReportScheduleDAO.bulk_delete_logs")
 def test_prune_log_soft_time_out(bulk_delete_logs, create_report_email_dashboard):
     from celery.exceptions import SoftTimeLimitExceeded
 
@@ -1984,9 +1976,7 @@ def test__send_with_client_errors(notification_mock, logger_mock):
 
     assert excinfo.errisinstance(SupersetException)
     logger_mock.warning.assert_called_with(
-        (
-            "SupersetError(message='', error_type=<SupersetErrorType.REPORT_NOTIFICATION_ERROR: 'REPORT_NOTIFICATION_ERROR'>, level=<ErrorLevel.WARNING: 'warning'>, extra=None)"
-        )
+        "SupersetError(message='', error_type=<SupersetErrorType.REPORT_NOTIFICATION_ERROR: 'REPORT_NOTIFICATION_ERROR'>, level=<ErrorLevel.WARNING: 'warning'>, extra=None)"
     )
 
 
@@ -2020,7 +2010,6 @@ def test__send_with_multiple_errors(notification_mock, logger_mock):
 @patch("superset.reports.commands.execute.logger")
 @patch("superset.reports.commands.execute.create_notification")
 def test__send_with_server_errors(notification_mock, logger_mock):
-
     notification_content = "I am some content"
     recipients = ["test@foo.com"]
     notification_mock.return_value.send.side_effect = NotificationError()
@@ -2030,7 +2019,5 @@ def test__send_with_server_errors(notification_mock, logger_mock):
     assert excinfo.errisinstance(SupersetException)
     # it logs the error
     logger_mock.warning.assert_called_with(
-        (
-            "SupersetError(message='', error_type=<SupersetErrorType.REPORT_NOTIFICATION_ERROR: 'REPORT_NOTIFICATION_ERROR'>, level=<ErrorLevel.ERROR: 'error'>, extra=None)"
-        )
+        "SupersetError(message='', error_type=<SupersetErrorType.REPORT_NOTIFICATION_ERROR: 'REPORT_NOTIFICATION_ERROR'>, level=<ErrorLevel.ERROR: 'error'>, extra=None)"
     )
