@@ -30,7 +30,6 @@ from superset.utils.core import (
     get_metric_names,
     get_time_filter_status,
     is_adhoc_metric,
-    NO_TIME_RANGE,
 )
 from tests.unit_tests.fixtures.datasets import get_dataset_mock
 
@@ -105,6 +104,18 @@ def test_get_metric_name_invalid_metric():
     with pytest.raises(ValueError):
         get_metric_name(metric)
 
+    metric = deepcopy(SQL_ADHOC_METRIC)
+    del metric["expressionType"]
+    with pytest.raises(ValueError):
+        get_metric_name(metric)
+
+    with pytest.raises(ValueError):
+        get_metric_name(None)
+    with pytest.raises(ValueError):
+        get_metric_name(0)
+    with pytest.raises(ValueError):
+        get_metric_name({})
+
 
 def test_get_metric_names():
     assert get_metric_names(
