@@ -15,15 +15,13 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from typing import Iterator
 
 import pytest
 from sqlalchemy.orm.session import Session
 
 
 def test_create_ssh_tunnel():
-    from superset.databases.dao import DatabaseDAO
-    from superset.databases.ssh_tunnel.dao import SSHTunnelDAO
+    from superset.daos.database import DatabaseDAO, SSHTunnelDAO
     from superset.databases.ssh_tunnel.models import SSHTunnel
     from superset.models.core import Database
 
@@ -37,7 +35,7 @@ def test_create_ssh_tunnel():
         "password": "bar",
     }
 
-    result = SSHTunnelDAO.create(properties)
+    result = SSHTunnelDAO.create(properties, commit=False)
 
     assert result is not None
     assert isinstance(result, SSHTunnel)
