@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from typing import Iterator
+from collections.abc import Iterator
 
 import pytest
 from sqlalchemy.orm.session import Session
@@ -46,7 +46,7 @@ def session_with_data(session: Session) -> Iterator[Session]:
 
 def test_datasource_find_by_id_skip_base_filter(session_with_data: Session) -> None:
     from superset.connectors.sqla.models import SqlaTable
-    from superset.datasets.dao import DatasetDAO
+    from superset.daos.dataset import DatasetDAO
 
     result = DatasetDAO.find_by_id(
         1,
@@ -63,7 +63,7 @@ def test_datasource_find_by_id_skip_base_filter(session_with_data: Session) -> N
 def test_datasource_find_by_id_skip_base_filter_not_found(
     session_with_data: Session,
 ) -> None:
-    from superset.datasets.dao import DatasetDAO
+    from superset.daos.dataset import DatasetDAO
 
     result = DatasetDAO.find_by_id(
         125326326,
@@ -75,7 +75,7 @@ def test_datasource_find_by_id_skip_base_filter_not_found(
 
 def test_datasource_find_by_ids_skip_base_filter(session_with_data: Session) -> None:
     from superset.connectors.sqla.models import SqlaTable
-    from superset.datasets.dao import DatasetDAO
+    from superset.daos.dataset import DatasetDAO
 
     result = DatasetDAO.find_by_ids(
         [1, 125326326],
@@ -92,7 +92,7 @@ def test_datasource_find_by_ids_skip_base_filter(session_with_data: Session) ->
 def test_datasource_find_by_ids_skip_base_filter_not_found(
     session_with_data: Session,
 ) -> None:
-    from superset.datasets.dao import DatasetDAO
+    from superset.daos.dataset import DatasetDAO
 
     result = DatasetDAO.find_by_ids(
         [125326326, 125326326125326326],
